<?php

/**
 * @file
 * Contains Drupal\wcm_simplesamlphp_auth\SimplesamlphpConfigurator
 * 
 * Simplesamlphp setup utilities. Can be used by composer hooks once added
 * to the autoload classmap section of composer.json.
 */

namespace wcm_site_scripts\composer;

use Composer\EventDispatcher\Event;
use Symfony\Component\Filesystem\Filesystem;

class SimplesamlphpConfigurator
{

    protected static function getProjectRoot()
    {
        return getcwd();
    }

    protected static function getDrupalRoot()
    {
        return static::getProjectRoot() . '/web';
    }

    public static function configureForPantheon(Event $event)
    {
        static::createWebUILink($event);
        static::createConfigLink($event);
    }

    public static function createWebUILink(Event $event)
    {
        echo 'Creating web symlink...' . PHP_EOL;
        // get drupal root
        $fs = new Filesystem();
        $drupal_root = static::getDrupalRoot();
        $project_root = static::getProjectRoot();
        // create link if it doesn't exist
        if (!$fs->exists($drupal_root . '/simplesaml')) {
            $target = $project_root . '/vendor/simplesamlphp/simplesamlphp/public/';
            $link_location = $drupal_root;
            $rel_target = $fs->makePathRelative($target, $link_location);
            $link = $link_location . '/simplesaml';
            symlink($rel_target, $link);
        }
    }

    public static function createConfigLink(Event $event)
    {
        // get drupal root
        $fs = new Filesystem();
        $root = static::getProjectRoot();
        // remove the vendor config dir if its still there
        $vendorConfigDir = $root . '/vendor/simplesamlphp/simplesamlphp/config';
        if ($fs->exists($vendorConfigDir) && is_dir($vendorConfigDir)) {
            echo 'Removing vendor config directory...' . PHP_EOL;
            $fs->remove($vendorConfigDir);
        }
        // create symlink
        echo 'Creating config symlink...' . PHP_EOL;
        $link_location = 'vendor/simplesamlphp/simplesamlphp/config';
        $target = '../../../private/simplesamlphp/config';
        symlink($target, $link_location);
    }
}
